"""
CPIC_get_alleles

Get pharmacogenomics alleles and their functional status for a gene from CPIC. Returns allele nam...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def CPIC_get_alleles(
    genesymbol: str,
    limit: Optional[int | Any] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get pharmacogenomics alleles and their functional status for a gene from CPIC. Returns allele nam...

    Parameters
    ----------
    genesymbol : str
        Gene symbol (e.g., 'CYP2D6', 'CYP2C19', 'TPMT', 'DPYD')
    limit : int | Any
        Maximum number of alleles to return (default 50)
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "CPIC_get_alleles",
            "arguments": {"genesymbol": genesymbol, "limit": limit},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["CPIC_get_alleles"]
